//=============================================================================
//	Step5
//
//	FileName	:	PP100APISampleStep5.cpp
//	Contents	:	Submit JOB PP-100 Series API sample application.
//	Language	:	C++
//	Copyright	:	Copyright(C) SEIKO EPSON CORPORATION 2010. All rights reserved.
//	Note		:
//	 1.Outline
//	  Initialize, connect to PC, submit JOB, cancel JOB, get JOB status, destroy, and output it return value to the console.
//	 2.Process
//	 (1)Initialize PP-100 Series API.
//		PP100_Initialize()
//	 (2)Connect to PC that TDBridge is running.
//		PP100_ConnectServer()
//	 (3)Create JOB and get JOB ID.Set JOB setting.Get JOB setting.
//		PP100_CreateJob(), PP100_SetDiscType(), PP100_GetDiscType()
//	 (4)Set JOB content. Get JOB content. [DATA]
//		PP100_SetData(), PP100_GetData()
//	 (5)Submit JOB.
//		PP100_SubmitJob()
//	 (6)Get JOB status.
//		PP100_GetJobStatus()
//	 (7)Disconnect from PC that TDBridge is running.
//		PP100_DisConnectServer()
//	 (8)Release PP-100 Series API.
//		PP100_Destroy()
//	CommandLine	:	PP100APISampleStep5
//=============================================================================

//=============================================================================
//	include files (#include)
//=============================================================================
#if defined(_WIN32)
#include <windows.h>
#include <tchar.h>
#include <shfolder.h>
#elif defined(__GNUC__)
#include <dlfcn.h>
#include <string.h>
#include <unistd.h>
#endif//defined(_WIN32),defined(__GNUC__)
#include <stdio.h>
#include "PP100API.h"

//=============================================================================
//	global variables
//=============================================================================
// The full path of PP100API.dll.
// If you changed the installation folder of EPSON TD Bridge, you need to changed the value.
#if defined(_WIN32)
TCHAR g_pPP100APIDLL[] = _T("\\EPSON\\TDBridge\\API\\PP100API.dll");
#elif defined(__GNUC__)
const char g_pPP100APIDLL[] = "/opt/epson/Total Disc Maker/lib/libPP100API.so";
#endif//defined(_WIN32),defined(__GNUC__)
HMODULE g_hPP100APIDLL = NULL;
PP100_INITIALIZE g_pPP100_Initialize = NULL;
PP100_DESTROY g_pPP100_Destroy = NULL;
PP100_CONNECTSERVER g_pPP100_ConnectServer = NULL;
PP100_DISCONNECTSERVER g_pPP100_DisConnectServer = NULL;
PP100_ENUMPUBLISHERS g_pPP100_EnumPublishers = NULL;
PP100_GETPUBLISHERSTATUS g_pPP100_GetPublisherStatus = NULL;
PP100_GETJOBSTATUS g_pPP100_GetJobStatus = NULL;
PP100_CREATEJOB g_pPP100_CreateJob = NULL;
PP100_SETDISCTYPE g_pPP100_SetDiscType = NULL;
PP100_GETDISCTYPE g_pPP100_GetDiscType = NULL;
PP100_SETDATA g_pPP100_SetData = NULL;
PP100_GETDATA g_pPP100_GetData = NULL;
PP100_SUBMITJOB g_pPP100_SubmitJob = NULL;
PP100_CANCELJOB g_pPP100_CancelJob = NULL;

//=============================================================================
//	global functions
//=============================================================================
long LoadPP100API(); // Load PP-100 Series API and get function pointers.
void DisplayJobStatus(PP100_JOB_STATUS pJobStatus[], unsigned long ulJobStatusNum);	// Display PP100_JOB_STATUS.

//=============================================================================
//	main
//
//	(1)Initialize PP-100 Series API.
//		PP100_Initialize()
//	(2)Connect to PC that TDBridge is running.
//		PP100_ConnectServer()
//	(3)Create JOB and get JOB ID.Set JOB setting.Get JOB setting.
//		PP100_CreateJob(), PP100_SetDiscType(), PP100_GetDiscType()
//	(4)Set JOB content. Get JOB content. [DATA]
//		PP100_SetData(), PP100_GetData()
//	(5)Submit JOB.
//		PP100_SubmitJob()
//	(6)Get JOB status.
//		PP100_GetJobStatus()
//	(7)Disconnect from PC that TDBridge is running.
//		PP100_DisConnectServer()
//	(8)Release PP-100 Series API.
//
//	IN:
//		argc		- Number of input parameter.
//		argv		- Pointer to input paraemter.
//	OUT:
//
//	Return: void
//=============================================================================
int main(int argc, char *argv[])
{
	long nRet = LoadPP100API();
	printf("LoadPP100API() returns %ld\n", nRet);
	if(0 != nRet)
	{
		printf("Loading PP-100 Series API failed.\n");
		return nRet;
	}

	//=========================================================================
	// (1)Initialize PP100 Series API.
	//=========================================================================
	nRet = g_pPP100_Initialize();
	printf("PP100_Initialize() returns %ld\n", nRet);
	if(PP100API_SUCCESS != nRet)
	{
		printf("Initializing PP-100 Series API failed.\n");
		return nRet;
	}

	//=========================================================================
	// (2)Connect to PC that TDBridge is running.
	//    This sample sets pHost: 127.0.0.1, pOrderFolder: Orders
	//    i.e. \\127.0.0.1\Orders is full path of monitoring folder.
	//    If pHost is NULL, PP-100 Series API assume that local PC specified, and ignore pOrderFolder parameter.
	//=========================================================================
	unsigned long ulHandle = 0;
	//nRet = g_pPP100_ConnectServer(L"127.0.0.1", L"Orders", &ulHandle);
#if defined(_WIN32)
	nRet = g_pPP100_ConnectServer(NULL, L"Orders", &ulHandle);
#elif defined(__GNUC__)
	nRet = g_pPP100_ConnectServer(NULL, NULL, &ulHandle);
#endif//defined(_WIN32),defined(__GNUC__)
	printf("PP100_ConnectServer() returns %ld\n", nRet);
	printf("ulHandle is %lu\n", ulHandle);
	if(PP100API_SUCCESS != nRet)
	{
		printf("Connecting to PC that TDBridge is running failed.\n");
		return nRet;
	}

	//=========================================================================
	// (3)Create JOB and get JOB ID.Set JOB setting.Get JOB setting.
	//=========================================================================
#if defined(_WIN32)
	wchar_t pJobID[41] = {0};
	nRet = g_pPP100_CreateJob(pJobID);
	printf("PP100_CreateJob() returns %ld\n", nRet);
	wprintf(L"pJobID is %s\n", pJobID);
#elif defined(__GNUC__)
	char pJobID[41] = {0};
	nRet = g_pPP100_CreateJob(pJobID);
	printf("PP100_CreateJob() returns %ld\n", nRet);
	printf("pJobID is %s\n", pJobID);
#endif//defined(_WIN32),defined(__GNUC__)
	if(PP100API_SUCCESS == nRet)
	{
		// Set JOB setting.If necessary, call the function(PP100_SetPublisher(),PP100_SetCopies(), and so on)
		nRet = g_pPP100_SetDiscType(pJobID, PP100API_CD);
		printf("PP100_SetDiscType() returns %ld\n", nRet);
		if(PP100API_SUCCESS == nRet)
		{
			unsigned long ulDiscType = PP100API_ERROR;
			nRet = g_pPP100_GetDiscType(pJobID, &ulDiscType);
			printf("PP100_GetDiscType() returns %ld\n", nRet);
			printf("ulDiscType is %lu\n", ulDiscType);
		}

		//=========================================================================
		// (4)Set JOB content. Get JOB content. [DATA]
		//=========================================================================

		// Labelw
		PP100_WRITE_DATA writeData = {0};
#if defined(_WIN32)
		(void) GetWindowsDirectoryW(writeData.pSourceData, _countof(writeData.pSourceData));
		(void) ::wcscat_s(writeData.pSourceData, _countof(writeData.pSourceData), L"\\NOTEPAD.EXE");

		(void) ::wcscpy_s(writeData.pDestinationData, _countof(writeData.pDestinationData), L"SAMPLE\\NOTEPAD.EXE");
#elif defined(__GNUC__)
		strcpy(writeData.pSourceData, "/etc/os-release");
		strcpy(writeData.pDestinationData, "etc/os-release");
#endif//defined(_WIN32),defined(__GNUC__)

		unsigned long ulWriteDataNum = 1;
		nRet = g_pPP100_SetData(pJobID, &writeData, ulWriteDataNum);
		printf("PP100_SetData() returns %ld\n", nRet);
		if(PP100API_SUCCESS == nRet)
		{
			PP100_WRITE_DATA writeData2 = {0};
			nRet = g_pPP100_GetData(pJobID, &writeData2, &ulWriteDataNum);
			printf("PP100_GetData() returns %ld\n", nRet);
#if defined(_WIN32)
			wprintf(L"writeData2.pSourceData is %s, writeData2.pDestinationData is %s\n", writeData2.pSourceData, writeData2.pDestinationData);
#elif defined(__GNUC__)
			printf("writeData2.pSourceData is %s, writeData2.pDestinationData is %s\n", writeData2.pSourceData, writeData2.pDestinationData);
#endif//defined(_WIN32),defined(__GNUC__)
		}
	}
	else
	{
		printf("Creating new JOB failed.\n");
		return nRet;
	}

	//=========================================================================
	// (5)Submit JOB.
	//=========================================================================
#if defined(_WIN32)
	if(0 != wcslen(pJobID))
#elif defined(__GNUC__)
	if(0 != strlen(pJobID))
#endif//defined(_WIN32),defined(__GNUC__)
	{
		nRet = g_pPP100_SubmitJob(ulHandle, pJobID, true);
		printf("PP100_SubmitJob() returns %ld\n", nRet);
	}

	//=========================================================================
	// (6)Get JOB Status.
	//=========================================================================
#if defined(_WIN32)
	if(0 != wcslen(pJobID))
#elif defined(__GNUC__)
	sleep(1);
	if(0 != strlen(pJobID))
#endif//defined(_WIN32),defined(__GNUC__)
	{
		PP100_JOB_STATUS jobStatus = {0};
		unsigned long ulJobStatusNum = 1;
		nRet = g_pPP100_GetJobStatus(ulHandle, pJobID, &jobStatus, &ulJobStatusNum);
		printf("PP100_GetJobStatus() returns %ld\n", nRet);
		if(PP100API_SUCCESS == nRet)
		{
			DisplayJobStatus(&jobStatus, ulJobStatusNum);
		}
		else
		{
			printf("Getting JOB Status failed.\n");
		}
	}

	//=========================================================================
	// Cancel JOB. if you want to cancel, enable following code.
	//=========================================================================
	//if(0 != wcslen(pJobID))
	//{
	//	nRet = g_pPP100_CancelJob(ulHandle, pJobID);
	//}

	//=========================================================================
	// (7)Disconnecting from PC that TDBridge is running.
	//=========================================================================
	nRet = g_pPP100_DisConnectServer(ulHandle);
	printf("PP100_DisConnectServer() returns %ld\n", nRet);
	if(PP100API_SUCCESS != nRet)
	{
		printf("Disconnecting from PC that TDBridge is running failed.\n");
		return nRet;
	}

	//=========================================================================
	// (8)Release PP100 Series API.
	//=========================================================================
	nRet = g_pPP100_Destroy();
	printf("PP100_Destroy() returns %ld\n", nRet);
	if(PP100API_SUCCESS != nRet)
	{
		printf("Destroying PP-100 Series API failed.\n");
		return nRet;
	}

	return nRet;
}

//=============================================================================
//	LoadPP100API
//
//	(1)Load PP-100 Series API and get function pointers.
//
//	IN:
//	OUT:
//
//	Return:	0	- success
//			1	- failure
//=============================================================================
long LoadPP100API()
{
	// Load PP100API.dll

#if defined(_WIN32)
	TCHAR tcDLLPath[MAX_PATH];
	HRESULT hResult;
	hResult = SHGetFolderPath(NULL, CSIDL_PROGRAM_FILES, NULL, 0, tcDLLPath);
	if(S_OK != hResult)
	{
		printf("Loading PP-100 Series API failed.\n");
		return 1;
	}

	_tcscat_s(tcDLLPath, _countof(tcDLLPath), g_pPP100APIDLL);

	g_hPP100APIDLL = ::LoadLibrary(tcDLLPath);
	if(NULL == g_hPP100APIDLL)
	{
		printf("Loading PP-100 Series API failed.\n");
		return 1;
	}

	// Get function pointer of PP100_Initialize() and PP100_Destroy()
	g_pPP100_Initialize = (PP100_INITIALIZE)GetProcAddress(g_hPP100APIDLL, FNSTR_PP100_INITIALIZE);
	g_pPP100_Destroy = (PP100_DESTROY)GetProcAddress(g_hPP100APIDLL, FNSTR_PP100_DESTROY);
	g_pPP100_ConnectServer = (PP100_CONNECTSERVER)GetProcAddress(g_hPP100APIDLL, FNSTR_PP100_CONNECTSERVER);
	g_pPP100_DisConnectServer = (PP100_DISCONNECTSERVER)GetProcAddress(g_hPP100APIDLL, FNSTR_PP100_DISCONNECTSERVER);
	g_pPP100_EnumPublishers = (PP100_ENUMPUBLISHERS)GetProcAddress(g_hPP100APIDLL, FNSTR_PP100_ENUMPUBLISHERS);
	g_pPP100_GetPublisherStatus = (PP100_GETPUBLISHERSTATUS)GetProcAddress(g_hPP100APIDLL, FNSTR_PP100_GETPUBLISHERSTATUS);
	g_pPP100_GetJobStatus = (PP100_GETJOBSTATUS)GetProcAddress(g_hPP100APIDLL, FNSTR_PP100_GETJOBSTATUS);
	g_pPP100_CreateJob = (PP100_CREATEJOB)GetProcAddress(g_hPP100APIDLL, FNSTR_PP100_CREATEJOB);
	g_pPP100_SetDiscType = (PP100_SETDISCTYPE)GetProcAddress(g_hPP100APIDLL, FNSTR_PP100_SETDISCTYPE);
	g_pPP100_GetDiscType = (PP100_GETDISCTYPE)GetProcAddress(g_hPP100APIDLL, FNSTR_PP100_GETDISCTYPE);
	g_pPP100_SetData = (PP100_SETDATA)GetProcAddress(g_hPP100APIDLL, FNSTR_PP100_SETDATA);
	g_pPP100_GetData = (PP100_GETDATA)GetProcAddress(g_hPP100APIDLL, FNSTR_PP100_GETDATA);
	g_pPP100_SubmitJob = (PP100_SUBMITJOB)GetProcAddress(g_hPP100APIDLL, FNSTR_PP100_SUBMITJOB);
	g_pPP100_CancelJob = (PP100_CANCELJOB)GetProcAddress(g_hPP100APIDLL, FNSTR_PP100_CANCELJOB);
#elif defined(__GNUC__)
	const char *the_path = g_pPP100APIDLL;
	g_hPP100APIDLL = dlopen(the_path, RTLD_LAZY);
	if(NULL == g_hPP100APIDLL)
	{
		printf("Loading PP-100 Series API failed.\n");
		return 1;
	}

	// Get function pointer of PP100_Initialize() and PP100_Destroy()
	g_pPP100_Initialize = (PP100_INITIALIZE)dlsym(g_hPP100APIDLL, FNSTR_PP100_INITIALIZE);
	g_pPP100_Destroy = (PP100_DESTROY)dlsym(g_hPP100APIDLL, FNSTR_PP100_DESTROY);
	g_pPP100_ConnectServer = (PP100_CONNECTSERVER)dlsym(g_hPP100APIDLL, FNSTR_PP100_CONNECTSERVER);
	g_pPP100_DisConnectServer = (PP100_DISCONNECTSERVER)dlsym(g_hPP100APIDLL, FNSTR_PP100_DISCONNECTSERVER);
	g_pPP100_EnumPublishers = (PP100_ENUMPUBLISHERS)dlsym(g_hPP100APIDLL, FNSTR_PP100_ENUMPUBLISHERS);
	g_pPP100_GetPublisherStatus = (PP100_GETPUBLISHERSTATUS)dlsym(g_hPP100APIDLL, FNSTR_PP100_GETPUBLISHERSTATUS);
	g_pPP100_GetJobStatus = (PP100_GETJOBSTATUS)dlsym(g_hPP100APIDLL, FNSTR_PP100_GETJOBSTATUS);
	g_pPP100_CreateJob = (PP100_CREATEJOB)dlsym(g_hPP100APIDLL, FNSTR_PP100_CREATEJOB);
	g_pPP100_SetDiscType = (PP100_SETDISCTYPE)dlsym(g_hPP100APIDLL, FNSTR_PP100_SETDISCTYPE);
	g_pPP100_GetDiscType = (PP100_GETDISCTYPE)dlsym(g_hPP100APIDLL, FNSTR_PP100_GETDISCTYPE);
	g_pPP100_SetData = (PP100_SETDATA)dlsym(g_hPP100APIDLL, FNSTR_PP100_SETDATA);
	g_pPP100_GetData = (PP100_GETDATA)dlsym(g_hPP100APIDLL, FNSTR_PP100_GETDATA);
	g_pPP100_SubmitJob = (PP100_SUBMITJOB)dlsym(g_hPP100APIDLL, FNSTR_PP100_SUBMITJOB);
	g_pPP100_CancelJob = (PP100_CANCELJOB)dlsym(g_hPP100APIDLL, FNSTR_PP100_CANCELJOB);
#endif//defined(_WIN32),defined(__GNUC__)
	if(	NULL == g_pPP100_Initialize ||
		NULL == g_pPP100_Destroy ||
		NULL == g_pPP100_ConnectServer ||
		NULL == g_pPP100_DisConnectServer ||
		NULL == g_pPP100_EnumPublishers ||
		NULL == g_pPP100_GetPublisherStatus ||
		NULL == g_pPP100_GetJobStatus ||
		NULL == g_pPP100_CreateJob ||
		NULL == g_pPP100_SetDiscType ||
		NULL == g_pPP100_GetDiscType ||
		NULL == g_pPP100_SetData ||
		NULL == g_pPP100_GetData ||
		NULL == g_pPP100_SubmitJob ||
		NULL == g_pPP100_CancelJob)
	{
		printf("Getting function address failed.\n");
		return 1;
	}

	return 0;
}

//=============================================================================

//=============================================================================
//	DisplayJobStatus
//
//	(1)Display PP100_JOB_STATUS.
//
//	IN:
//		pJobStatus		- Pointer to PP100_JOB_STATUS array.
//		ulJobStatusNum	- Number of array.
//	OUT:
//
//	Return: void
//=============================================================================
void DisplayJobStatus(PP100_JOB_STATUS pJobStatus[], unsigned long ulJobStatusNum)
{
	for(unsigned long ul = 0; ul < ulJobStatusNum; ul++)
	{
#if defined(_WIN32)
		wprintf(L"\tpJobStatus[%lu].pJobID: %s\n", ul, pJobStatus[ul].pJobID);
		wprintf(L"\tpJobStatus[%lu].pPublisherName: %s\n", ul, pJobStatus[ul].pPublisherName);
		wprintf(L"\tpJobStatus[%lu].ulJobStatus: %lu\n", ul, pJobStatus[ul].ulJobStatus);
		wprintf(L"\tpJobStatus[%lu].ulErrorCode: %lu\n", ul, pJobStatus[ul].ulErrorCode);
		wprintf(L"\tpJobStatus[%lu].ulPublicationNumber: %lu\n", ul, pJobStatus[ul].ulPublicationNumber);
		wprintf(L"\tpJobStatus[%lu].ulCompletionNumber: %lu\n", ul, pJobStatus[ul].ulCompletionNumber);
		wprintf(L"\tpJobStatus[%lu].ulJobType: %lu\n", ul, pJobStatus[ul].ulJobType);
		wprintf(L"\tpJobStatus[%lu].ulSource: %lu\n", ul, pJobStatus[ul].ulSource);
		wprintf(L"\tpJobStatus[%lu].ulDestination: %lu\n", ul, pJobStatus[ul].ulDestination);
		wprintf(L"\tpJobStatus[%lu].ulJobIndex: %lu\n", ul, pJobStatus[ul].ulJobIndex);
		wprintf(L"\tpJobStatus[%lu].ulEstimateTime: %lu\n", ul, pJobStatus[ul].ulEstimateTime);
		wprintf(L"\tpJobStatus[%lu].ulErrorNumber: %lu\n", ul, pJobStatus[ul].ulErrorNumber);
		wprintf(L"\tpJobStatus[%lu].ulMode: %lu\n", ul, pJobStatus[ul].ulMode);
		wprintf(L"\tpJobStatus[%lu].ucIsSubmittedByTotalDiscMaker: %hhu\n", ul, pJobStatus[ul].ucIsSubmittedByTotalDiscMaker);
#elif defined(__GNUC__)
		printf("\tpJobStatus[%lu].pJobID: %s\n", ul, pJobStatus[ul].pJobID);
		printf("\tpJobStatus[%lu].pPublisherName: %s\n", ul, pJobStatus[ul].pPublisherName);
		printf("\tpJobStatus[%lu].ulJobStatus: %lu\n", ul, pJobStatus[ul].ulJobStatus);
		printf("\tpJobStatus[%lu].ulErrorCode: %lu\n", ul, pJobStatus[ul].ulErrorCode);
		printf("\tpJobStatus[%lu].ulPublicationNumber: %lu\n", ul, pJobStatus[ul].ulPublicationNumber);
		printf("\tpJobStatus[%lu].ulCompletionNumber: %lu\n", ul, pJobStatus[ul].ulCompletionNumber);
		printf("\tpJobStatus[%lu].ulJobType: %lu\n", ul, pJobStatus[ul].ulJobType);
		printf("\tpJobStatus[%lu].ulSource: %lu\n", ul, pJobStatus[ul].ulSource);
		printf("\tpJobStatus[%lu].ulDestination: %lu\n", ul, pJobStatus[ul].ulDestination);
		printf("\tpJobStatus[%lu].ulJobIndex: %lu\n", ul, pJobStatus[ul].ulJobIndex);
		printf("\tpJobStatus[%lu].ulEstimateTime: %lu\n", ul, pJobStatus[ul].ulEstimateTime);
		printf("\tpJobStatus[%lu].ulErrorNumber: %lu\n", ul, pJobStatus[ul].ulErrorNumber);
		printf("\tpJobStatus[%lu].ulMode: %lu\n", ul, pJobStatus[ul].ulMode);
		printf("\tpJobStatus[%lu].ucIsSubmittedByTotalDiscMaker: %hhu\n", ul, pJobStatus[ul].ucIsSubmittedByTotalDiscMaker);
#endif//defined(_WIN32),defined(__GNUC__)
	}
}
