#include <QtCore/QtCore>
#include <QtCore/QThread>
#include <QApplication>   // Qt4: QtGui/QApplication,    Qt5: QtWidgets/QApplication
#include <QMainWindow>    // Qt4: QtGui/QMainWindow,     Qt5: QtWidgets/QMainWindow
#include <QDesktopWidget> // Qt4: QtGui/QDesktopWidget,  Qt5: QtWidgets/QDesktopWidget

#include <QMessageBox>
#include <QFileDialog>
#include <QMenu>
#include <QtGui/QStandardItemModel> // Qt4: QtGui/QStandardItemModel,   Qt5: QtGui/QStandardItemModel

#include <QGraphicsScene>
#include <QGraphicsEllipseItem>
#include <QGraphicsPathItem>
#include <QGraphicsPixmapItem>

#include <QtGui/QDragEnterEvent>

#include <QtGui/QImageReader> // Qt4: QtGui/QImageReader,   Qt5: QtGui/QImageReader
#include <QtGui/QImageWriter> // Qt4: QtGui/QImageWriter,   Qt5: QtGui/QImageWriter

#include <regex>
#include <memory>
#include <utility>
//#include <functional>
//#include <unistd.h> // sleep, usleep
#include <dlfcn.h> // dlopen, dlsym
#include <assert.h>

#include "config.h"

bool verbose = false;
#if !defined(verbose_print)
#define verbose_print(...) if(verbose)fprintf(stderr,__VA_ARGS__)
#endif//!defined(verbose_print)

#include "countof.h"

#if !defined(QT_VERSION)
LSBのQT(4.2.0)は、QT_VERSIONが無い。
#define QT_BEGIN_NAMESPACE // uic generate it, but Qt4@lsb doesn't support.
#define QT_END_NAMESPACE   // uic generate it, but Qt4@lsb doesn't support.
#error
#endif

#include "ui_TDMakerLite.h"

#include <unistd.h>
#include "PP100API.h"
const char g_pPP100APIDLL[] = "/opt/epson/Total Disc Maker/lib/libPP100API.so";

#define	TMPPATH		"/tmp"

int systemf(const char fmt[], ...)
{
	static char cmd[2048] = {};

	va_list		ArgList;
	va_start(ArgList, fmt);
	(void) vsprintf(cmd, fmt, ArgList);
	va_end(ArgList);

	printf("systemf, [%s]\n", cmd);
	QProcess process;
	process.start(cmd);
	if(process.waitForFinished(30000)) // msec
	{
		if ( process.exitCode() != 0 )
		{
			printf("\tstdout: %s\n", qPrintable(process.readAllStandardOutput()));
			printf("\tstderr: %s\n", qPrintable(process.readAllStandardError()));
			printf("\texit code: %d\n", process.exitCode());
		}
		return process.exitCode();
	}
	else
	{
		printf("failed: %s\n", qPrintable(process.errorString()));
	}
	process.close();
	return -1;
}

std::string popen_fgets_f(const char fmt[], ...)
{
	static char cmd[2048] = {};

	va_list		ArgList;
	va_start(ArgList, fmt);
	(void) vsprintf(cmd, fmt, ArgList);
	va_end(ArgList);

	FILE * fp = ::popen(cmd, "r");
	if ( fp != NULL )
	{
		char result[1024] = {};
		if(::fgets(result, 1024, fp))
		{
			(void) ::pclose(fp);
			return std::string(result);
		}
		(void) ::pclose(fp);
	}
	return std::string();
}


int svg2png(const char svgfile[], char pngfile_tmp[])
{
	(void)sprintf(pngfile_tmp, "%s/.tmpXXXXXX.png", TMPPATH);
	int fd = ::mkstemps(pngfile_tmp, 4);
	if (fd == -1)
	{
		fprintf(stderr, "svg2png, png tmp file (%s) mkstemps error(errno:%d)\n", pngfile_tmp, errno);
		return -2;
	}
	(void)close(fd);

	double width = 0.0;
	double height = 0.0;
	std::string widthStr = popen_fgets_f("inkscape -z -W \"%s\"", svgfile);
	std::string heightStr = popen_fgets_f("inkscape -z -H \"%s\"", svgfile);

	if ( ! widthStr.empty() )
	{
		width = strtof( widthStr.c_str(), NULL );
	}
	if ( ! heightStr.empty() )
	{
		height = strtof( heightStr.c_str(), NULL );
	}

	int ret = -1;
	int imageSizeDot = 200; // just for preview

	if ( width > 0.0 && height > 0.0 )
	{
		if ( width > height )
		{
			ret = systemf("inkscape -z -w %d -e \"%s\" \"%s\"", imageSizeDot, pngfile_tmp, svgfile);
		}
		else
		{
			ret = systemf("inkscape -z -h %d -e \"%s\" \"%s\"", imageSizeDot, pngfile_tmp, svgfile);
		}
	}
	else
	{
		ret = systemf("inkscape -z -w %d -h %d -e \"%s\" \"%s\"", imageSizeDot, imageSizeDot, pngfile_tmp, svgfile);
	}

	if (ret == -1 || ret == 32512)
	{
		if ( errno == ENOENT )
		{
			fprintf(stderr, "LabelRenderer::svg2png, failed to launch inkscape, it may not be installed.\n");
		}
		else
		{
			fprintf(stderr, "LabelRenderer::svg2png, failed to launch inkscape with errno %d\n", errno);
		}

		return -4;
	}
	if (ret != 0)
	{
		fprintf(stderr, "svg2png, inkscape retuned error code %d\n", ret);
		return -4;
	}

	return 1;
}


// -----------------------------------------------------------------------------------------------
class MainFrame : public QWidget
{
	Q_OBJECT

	Ui::TDMakerLite ui;

	QStandardItemModel * modelContent = nullptr;
	QAction * actionRemove = nullptr;
	QAction * actionAddFile = nullptr;
	QAction * actionAddFolder = nullptr;

	qreal textModePointSizeDefault = 0.0f;
	int textModePointSizeMargin = 22;	// 11 * 2

	struct {
		QGraphicsScene * scene;
		QPixmap intenalPixmap;
		QGraphicsPixmapItem * labelImage;
		QGraphicsEllipseItem * ellipseLabelInner;
		QGraphicsPathItem * ellipseLabelOuter;
		QGraphicsEllipseItem * ellipseDiscInner;
		QGraphicsPathItem * ellipseDiscOuter;
	} sceneLabelPreview;

public:
	explicit MainFrame(void)
	{
		ui.setupUi(this);
		this->setObjectName(QString::fromUtf8("MainFrame"));
		this->setWindowTitle("EPSON Total Disc Maker Lite");
		this->setWindowIcon(QIcon(QString::fromUtf8("://images/TDMaker.png")));

		this->setGeometry(
			QStyle::alignedRect(
				Qt::LeftToRight,
				Qt::AlignCenter,
				size(),
				QApplication::desktop()->availableGeometry()
			)
		);

		modelContent = new QStandardItemModel();
		ui.listViewContent->setModel(modelContent);
		ui.listViewContent->setContextMenuPolicy(Qt::CustomContextMenu);
		actionRemove    = new QAction(tr("Delete From Write Data"), this);
		actionAddFile   = new QAction(tr("Add File"), this);
		actionAddFolder = new QAction(tr("Add Folder"), this);

		sceneLabelPreview.scene = new QGraphicsScene((QRect(0, 0, 240, 240)));
		ui.viewLabelPreview->setScene(sceneLabelPreview.scene);

		sceneLabelPreview.labelImage = new QGraphicsPixmapItem();
		sceneLabelPreview.ellipseLabelInner = new QGraphicsEllipseItem();
		sceneLabelPreview.ellipseLabelOuter = new QGraphicsPathItem();
		sceneLabelPreview.ellipseDiscInner = new QGraphicsEllipseItem();
		sceneLabelPreview.ellipseDiscOuter = new QGraphicsPathItem();
		sceneLabelPreview.scene->addItem(sceneLabelPreview.labelImage);
		sceneLabelPreview.scene->addItem(sceneLabelPreview.ellipseLabelInner);
		sceneLabelPreview.scene->addItem(sceneLabelPreview.ellipseLabelOuter);
		sceneLabelPreview.scene->addItem(sceneLabelPreview.ellipseDiscInner);
		sceneLabelPreview.scene->addItem(sceneLabelPreview.ellipseDiscOuter);

		sceneLabelPreview.ellipseLabelInner->setOpacity(.4);
		sceneLabelPreview.ellipseLabelOuter->setOpacity(.4);
		sceneLabelPreview.ellipseDiscInner->setOpacity(.6);
		sceneLabelPreview.ellipseDiscOuter->setOpacity(.6);
		sceneLabelPreview.ellipseLabelInner->setBrush(QBrush(QColor("white")));
		sceneLabelPreview.ellipseLabelOuter->setBrush(QBrush(QColor("white")));
		sceneLabelPreview.ellipseDiscInner->setBrush(QBrush(QColor("white")));
		sceneLabelPreview.ellipseDiscOuter->setBrush(QBrush(QColor("white")));

		int diameterInner = ui.spinDiameterInside->value() * 10; // [mm]
		int diameterOuter = ui.spinDiameterOutside->value() * 10; // [mm]
		sceneLabelPreview.ellipseLabelInner->setRect(120 - diameterInner, 120 - diameterInner, diameterInner*2, diameterInner*2);
		sceneLabelPreview.ellipseDiscInner->setRect(120 - 15, 120 - 15, 15*2, 15*2);

		QPainterPath pathWhole;
		pathWhole.addRect(QRectF(0-10, 0-10, 240+10*2, 240+10*2));
		QPainterPath pathLabelOuter;
		pathLabelOuter.addEllipse(QRectF(120 - diameterOuter, 120 - diameterOuter, diameterOuter*2, diameterOuter*2));
		QPainterPath pathDiscOuter;
		pathDiscOuter.addEllipse(QRectF(120 - 120, 120 - 120, 120*2, 120*2));
		sceneLabelPreview.ellipseLabelOuter->setPath(pathWhole - pathLabelOuter);
		sceneLabelPreview.ellipseDiscOuter->setPath(pathWhole - pathDiscOuter);

		// Button response on start up window
		QObject::connect(ui.btnAddFile, SIGNAL(clicked()), this, SLOT(onAddFileClicked()) );
		QObject::connect(ui.btnAddFolder, SIGNAL(clicked()), this, SLOT(onAddFolderClicked()) );
		QObject::connect(
			ui.listViewContent,
			SIGNAL(customContextMenuRequested(const QPoint &)),
			SLOT(onContentContextMenuRequested(const QPoint &)));
		QObject::connect(actionRemove, SIGNAL(triggered()), this, SLOT(onRemoveItemClicked()) );
		QObject::connect(actionAddFile, SIGNAL(triggered()), this, SLOT(onAddFileClicked()) );
		QObject::connect(actionAddFolder, SIGNAL(triggered()), this, SLOT(onAddFolderClicked()) );

		QObject::connect(ui.btnSelectLabelFile, SIGNAL(clicked()), this, SLOT(onSelectLabelFileClicked()) );
		QObject::connect(ui.spinDiameterInside, SIGNAL(valueChanged(double)), this, SLOT(onDiameterChanged()) );
		QObject::connect(ui.spinDiameterOutside, SIGNAL(valueChanged(double)), this, SLOT(onDiameterChanged()) );

		QObject::connect(ui.btnPublish, SIGNAL(clicked()), this, SLOT(onPublishClicked()) );
		QObject::connect(ui.btnLaunchTDSetup, SIGNAL(clicked()), this, SLOT(onLaunchTDSetupClicked()) );

		QObject::connect(ui.selectStackerIn, SIGNAL(currentIndexChanged(int)), this, SLOT(onCheckStateChanged()) );
		QObject::connect(ui.selectStackerOut, SIGNAL(currentIndexChanged(int)), this, SLOT(onCheckStateChanged()) );
		QObject::connect(ui.checkWriteData, SIGNAL(stateChanged(int)), this, SLOT(onCheckStateChanged()) );
		QObject::connect(ui.checkPrintLabel, SIGNAL(stateChanged(int)), this, SLOT(onCheckStateChanged()) );

		// ComboBox response on start up window
		QObject::connect(ui.selectOutputDevice, SIGNAL(currentIndexChanged(int)), this, SLOT(onOutputDeviceChanged()) );

		setAcceptDrops(true);


		// PP100API
		if ( ! LoadPP100API() )
		{
			(void) QMessageBox::critical(
				this,
				tr("EPSON Total Disc Maker Lite"),
				tr("Loading PP-100 Series API failed.\n") + m_dlerror.c_str());
			throw (int) -1;
		}

		if( PP100_Initialize() != PP100API_SUCCESS )
		{
			(void) QMessageBox::critical(
				this,
				tr("EPSON Total Disc Maker Lite"),
				tr("PP100_Initialize failed.\n") + m_dlerror.c_str());
			throw (int) -1;
		}

		if ( PP100_ConnectServer(NULL, NULL, &m_ulPP100APIServerHandle) != PP100API_SUCCESS )
		{
			(void) QMessageBox::critical(
				this,
				tr("EPSON Total Disc Maker Lite"),
				tr("PP100_ConnectServer failed.\n") + m_dlerror.c_str());
			throw (int) -1;
		}

		// Adjust all widgets size and layout, then fix them.
		adjustSize();
		setFixedSize(width(), height());

		textModePointSizeDefault = ui.textMode->font().pointSizeF();
		setupOutputDeviceList();
	}


	virtual ~MainFrame(void)
	{
		if ( PP100_DisConnectServer != NULL )
		{
			(void) PP100_DisConnectServer(m_ulPP100APIServerHandle);
		}
		if ( PP100_Destroy != NULL )
		{
			(void) PP100_Destroy();
		}
	}


protected:
	void setupOutputDeviceList(void)
	{
		ui.selectOutputDevice->clear();

		unsigned long ulEnumPublisherInfoNum = 0;
		std::vector<PP100_ENUM_PUBLISHER_INFO> vEnumPublisherInfo;
		int nRet = PP100_EnumPublishers(m_ulPP100APIServerHandle, &vEnumPublisherInfo[0], &ulEnumPublisherInfoNum);
		if(PP100API_MORE_ITEMS == nRet)
		{
			while(PP100API_MORE_ITEMS == nRet)
			{
				vEnumPublisherInfo.resize(ulEnumPublisherInfoNum);
				memset(&vEnumPublisherInfo[0], 0, sizeof(PP100_ENUM_PUBLISHER_INFO) * ulEnumPublisherInfoNum);
				nRet = PP100_EnumPublishers(m_ulPP100APIServerHandle, &vEnumPublisherInfo[0], &ulEnumPublisherInfoNum);
			}
		}
		if(PP100API_SUCCESS == nRet)
		{
			for(auto info : vEnumPublisherInfo)
			{
				ui.selectOutputDevice->addItem(QString::fromUtf8(info.pPublisherName));
			}

			return;
		}
	}


	bool addPathItem(const QString& path)
	{
		if (!path.isEmpty())
		{
			QStandardItem * item = new QStandardItem();
			Q_CHECK_PTR(item);

			QFileInfo info(path);
			item->setText( info.fileName() );
			item->setToolTip( path );
			item->setEditable( false );
			if ( info.isDir() )
			{
				item->setIcon( QApplication::style()->standardIcon( QStyle::SP_DirIcon ) );
			}
			else
			{
				item->setIcon( QApplication::style()->standardIcon( QStyle::SP_FileIcon ) );
			}
			modelContent->appendRow( item );
			ui.checkWriteData->setChecked(true);
		}
		return true;
	}

	void rescaleFontToFitContent(QWidget* widget, const QString& content, qreal pointFDefault, qreal pointFMin)
	{
		qreal pointF = pointFDefault;
		QFont font = widget->font();
		font.setPointSizeF(pointF);
		widget->setFont(font);

		int areaWidth = widget->size().width() - textModePointSizeMargin;
		int contentWidth = widget->fontMetrics().boundingRect(content).width();
		for(
			int i=0;
			(i < 10) && (areaWidth < contentWidth) && (pointF >= pointFMin);
			i++ )
		{
			pointF = pointF * areaWidth / contentWidth * 0.98;
			font.setPointSizeF(pointF);
			widget->setFont(font);
			contentWidth = widget->fontMetrics().boundingRect(content).width();
		}
	}

private:
	// PP100API Functions
	HMODULE m_hPP100APIDLL = NULL;
	std::string m_dlerror;
	PP100_INITIALIZE         PP100_Initialize = NULL;
	PP100_DESTROY            PP100_Destroy = NULL;
	PP100_CONNECTSERVER      PP100_ConnectServer = NULL;
	PP100_DISCONNECTSERVER   PP100_DisConnectServer = NULL;
	PP100_ENUMPUBLISHERS     PP100_EnumPublishers = NULL;
	PP100_GETPUBLISHERSTATUS PP100_GetPublisherStatus = NULL;
	PP100_GETJOBSTATUS       PP100_GetJobStatus = NULL;
	PP100_CREATEJOB          PP100_CreateJob = NULL;
	PP100_SETPUBLISHER       PP100_SetPublisher = NULL;
	PP100_SETDISCTYPE        PP100_SetDiscType = NULL;
	PP100_SETOUTSTACKER      PP100_SetOutStacker = NULL;
	PP100_SETINSTACKER       PP100_SetInStacker = NULL;
	PP100_SETCOMPARE         PP100_SetCompare = NULL;
	PP100_SETFORMAT          PP100_SetFormat = NULL;
	PP100_SETVOLUMELABEL     PP100_SetVolumeLabel = NULL;
	PP100_SETDATA            PP100_SetData = NULL;
	PP100_SETLABEL           PP100_SetLabel = NULL;
	PP100_SETLABELTYPE       PP100_SetLabelType = NULL;
	PP100_SETPRINTMODE       PP100_SetPrintMode = NULL;
	PP100_SETLABELAREA       PP100_SetLabelArea = NULL;
	PP100_SETCOPIES          PP100_SetCopies = NULL;
	PP100_SUBMITJOB          PP100_SubmitJob = NULL;

	unsigned long m_ulPP100APIServerHandle = 0;

protected:
	bool LoadPP100API()
	{
		m_hPP100APIDLL = dlopen(g_pPP100APIDLL, RTLD_LAZY);
		if(NULL == m_hPP100APIDLL)
		{
			m_dlerror = dlerror();
			fprintf(stderr, "Loading PP-100 Series API failed. errno: %d\n%s\n", errno, m_dlerror.c_str());
			return false;
		}

		// Get function pointer of PP100_Initialize() and PP100_Destroy()
		PP100_Initialize = (PP100_INITIALIZE)dlsym(m_hPP100APIDLL, FNSTR_PP100_INITIALIZE);
		PP100_Destroy = (PP100_DESTROY)dlsym(m_hPP100APIDLL, FNSTR_PP100_DESTROY);
		PP100_ConnectServer = (PP100_CONNECTSERVER)dlsym(m_hPP100APIDLL, FNSTR_PP100_CONNECTSERVER);
		PP100_DisConnectServer = (PP100_DISCONNECTSERVER)dlsym(m_hPP100APIDLL, FNSTR_PP100_DISCONNECTSERVER);
		PP100_EnumPublishers = (PP100_ENUMPUBLISHERS)dlsym(m_hPP100APIDLL, FNSTR_PP100_ENUMPUBLISHERS);
		PP100_GetPublisherStatus = (PP100_GETPUBLISHERSTATUS)dlsym(m_hPP100APIDLL, FNSTR_PP100_GETPUBLISHERSTATUS);
		PP100_GetJobStatus = (PP100_GETJOBSTATUS)dlsym(m_hPP100APIDLL, FNSTR_PP100_GETJOBSTATUS);
		PP100_CreateJob = (PP100_CREATEJOB)dlsym(m_hPP100APIDLL, FNSTR_PP100_CREATEJOB);
		PP100_SetPublisher = (PP100_SETPUBLISHER)dlsym(m_hPP100APIDLL, FNSTR_PP100_SETPUBLISHER);
		PP100_SetDiscType = (PP100_SETDISCTYPE)dlsym(m_hPP100APIDLL, FNSTR_PP100_SETDISCTYPE);
		PP100_SetOutStacker = (PP100_SETOUTSTACKER)dlsym(m_hPP100APIDLL, FNSTR_PP100_SETOUTSTACKER);
		PP100_SetInStacker = (PP100_SETINSTACKER)dlsym(m_hPP100APIDLL, FNSTR_PP100_SETINSTACKER);
		PP100_SetCompare = (PP100_SETCOMPARE)dlsym(m_hPP100APIDLL, FNSTR_PP100_SETCOMPARE);
		PP100_SetFormat = (PP100_SETFORMAT)dlsym(m_hPP100APIDLL, FNSTR_PP100_SETFORMAT);
		PP100_SetVolumeLabel = (PP100_SETVOLUMELABEL)dlsym(m_hPP100APIDLL, FNSTR_PP100_SETVOLUMELABEL);
		PP100_SetData = (PP100_SETDATA)dlsym(m_hPP100APIDLL, FNSTR_PP100_SETDATA);
		PP100_SetLabel = (PP100_SETLABEL)dlsym(m_hPP100APIDLL, FNSTR_PP100_SETLABEL);
		PP100_SetLabelType = (PP100_SETLABELTYPE)dlsym(m_hPP100APIDLL, FNSTR_PP100_SETLABELTYPE);
		PP100_SetPrintMode = (PP100_SETPRINTMODE)dlsym(m_hPP100APIDLL, FNSTR_PP100_SETPRINTMODE);
		PP100_SetLabelArea = (PP100_SETLABELAREA)dlsym(m_hPP100APIDLL, FNSTR_PP100_SETLABELAREA);
		PP100_SetCopies = (PP100_SETCOPIES)dlsym(m_hPP100APIDLL, FNSTR_PP100_SETCOPIES);
		PP100_SubmitJob = (PP100_SUBMITJOB)dlsym(m_hPP100APIDLL, FNSTR_PP100_SUBMITJOB);

		if(	NULL == PP100_Initialize ||
			NULL == PP100_Destroy ||
			NULL == PP100_ConnectServer ||
			NULL == PP100_DisConnectServer ||
			NULL == PP100_EnumPublishers ||
			NULL == PP100_GetPublisherStatus ||
			NULL == PP100_GetJobStatus ||
			NULL == PP100_CreateJob ||
			NULL == PP100_SetPublisher ||
			NULL == PP100_SetDiscType ||
			NULL == PP100_SetOutStacker ||
			NULL == PP100_SetInStacker ||
			NULL == PP100_SetCompare ||
			NULL == PP100_SetFormat ||
			NULL == PP100_SetVolumeLabel ||
			NULL == PP100_SetData ||
			NULL == PP100_SetLabel ||
			NULL == PP100_SetLabelType ||
			NULL == PP100_SetPrintMode ||
			NULL == PP100_SetLabelArea ||
			NULL == PP100_SetCopies ||
			NULL == PP100_SubmitJob)
		{
			m_dlerror = dlerror();
			fprintf(stderr, "Getting function address failed. errno: %d%s\n", errno, m_dlerror.c_str());
			(void) dlclose(m_hPP100APIDLL);
			m_hPP100APIDLL = NULL;
			return false;
		}

		return true;
	}


private slots:
	bool onAddFileClicked(void)
	{
		QString filter0 = tr("All Files (*.*)");
		QString fileName = QFileDialog::getOpenFileName(
			this,
			tr("Add File"),
			NULL,
			filter0,
			&filter0,
			QFileDialog::DontUseCustomDirectoryIcons );
		if (!fileName.isEmpty())
		{
			addPathItem(fileName);
		}
		return true;
	}


	bool onAddFolderClicked(void)
	{
		QString dirName = QFileDialog::getExistingDirectory(
			this,
			tr("Add Folder"),
			NULL );
		if (!dirName.isEmpty())
		{
			addPathItem(dirName);
		}
		return true;
	}


	bool onRemoveItemClicked(void)
	{
		auto selectionModel = ui.listViewContent->selectionModel();
		auto indexes = selectionModel->selectedIndexes();
		size_t total = indexes.size();

		for(size_t i=0; i < total && !indexes.empty(); i++)
		{
			modelContent->removeRow(indexes[0].row());
			indexes = selectionModel->selectedIndexes();
		}
		return true;
	}


	bool onContentContextMenuRequested(const QPoint & pos)
	{
		QMenu contextMenu(tr("Write Data"), this);
		int row = ui.listViewContent->indexAt(pos).row();
		if ( row != -1 )
		{
			contextMenu.addAction(actionRemove);
		}
		else
		{
			contextMenu.addAction(actionAddFile);
			contextMenu.addAction(actionAddFolder);
		}
		contextMenu.exec(ui.listViewContent->mapToGlobal(pos));
		return true;
	}

	bool onSelectLabelFileClicked(void)
	{
		QString filter0 = tr("Picture File") + " (*.svg *.png *.jpg *.jpeg *.jpe *.jfif)";
		QString filter1 = tr("SVG") + " (*.svg)";
		QString filter2 = tr("PNG") + " (*.png)";
		QString filter3 = tr("JPEG") + " (*.jpg *.jpeg *.jpe *.jfif)";
		QString fileName = QFileDialog::getOpenFileName(
			this,
			tr("Select Image"),
			NULL,
			filter0 + ";;" + filter1 + ";;" + filter2 + ";;" + filter3,
			&filter0,
			QFileDialog::DontUseCustomDirectoryIcons
		);
		if (!fileName.isEmpty())
		{
			// load image to preview
			ui.textLabelFile->setText(fileName);
			bool bLoaded = false;
			if ( fileName.right(4).compare(".svg") == 0 )
			{
				char pngfile_tmp[1024] = {};
				int ret = svg2png(fileName.toUtf8().data(), pngfile_tmp);
				if(ret <= 0)
				{
					fprintf(stderr, "create PNG file error\n");
				}
				else
				{
					bLoaded = sceneLabelPreview.intenalPixmap.load(pngfile_tmp);
					// remove png temp file
					QFile::remove(pngfile_tmp);
				}
			}
			else
			{
				bLoaded = sceneLabelPreview.intenalPixmap.load(fileName);
			}
			if( !bLoaded)
			{
				(void) QMessageBox::warning(
					this,
					tr("Failed"),
					tr("Failed to load image for preview"));
				return false;
			}

			int diameterOuter = ui.spinDiameterOutside->value() * 10; // [mm]

			QPixmap scaledPixmap = sceneLabelPreview.intenalPixmap.scaled(diameterOuter*2, diameterOuter*2, Qt::KeepAspectRatio);
			sceneLabelPreview.labelImage->setOffset(120 - scaledPixmap.width()/2, 120 - scaledPixmap.height()/2);
			sceneLabelPreview.labelImage->setPixmap(scaledPixmap);

			ui.checkPrintLabel->setChecked(true);
			return true;
		}
		return false;
	}


	bool onDiameterChanged(void)
	{
		int diameterInner = ui.spinDiameterInside->value() * 10; // [mm]
		int diameterOuter = ui.spinDiameterOutside->value() * 10; // [mm]
		sceneLabelPreview.ellipseLabelInner->setRect(120 - diameterInner, 120 - diameterInner, diameterInner*2, diameterInner*2);
		QPainterPath pathWhole;
		pathWhole.addRect(QRectF(0-10, 0-10, 240+10*2, 240+10*2));
		QPainterPath pathLabelOuter;
		pathLabelOuter.addEllipse(QRectF(120 - diameterOuter, 120 - diameterOuter, diameterOuter*2, diameterOuter*2));
		sceneLabelPreview.ellipseLabelOuter->setPath(pathWhole - pathLabelOuter);

		QPixmap scaledPixmap = sceneLabelPreview.intenalPixmap.scaled(diameterOuter*2, diameterOuter*2, Qt::KeepAspectRatio);
		sceneLabelPreview.labelImage->setOffset(120 - scaledPixmap.width()/2, 120 - scaledPixmap.height()/2);
		sceneLabelPreview.labelImage->setPixmap(scaledPixmap);
		return true;
	}


	bool onLaunchTDSetupClicked(void)
	{
		QString currentOutputDevice = ui.selectOutputDevice->currentText();
		int res = QProcess::execute(QString::asprintf("pkexec \"/opt/epson/Total Disc Maker/bin/TDSetup\" \"%s\"", currentOutputDevice.toUtf8().data() ));
		printf("%d\n", res);
		if ( res == -2 || res == -1 )
		{
			(void) QMessageBox::warning(
				this,
				tr("Failed"),
				tr("Failed to launch TDSetup"));
			return false;
		}
		setupOutputDeviceList();
		ui.selectOutputDevice->setCurrentText(currentOutputDevice);
		return true;
	}


	bool SetJobParam(char pJobID[41])
	{
		long nRet = PP100API_SUCCESS;

		assert(ui.selectStackerIn->currentIndex() != -1);
		int nStackerIn = ui.selectStackerIn->currentData().value<std::pair<int,unsigned long>>().first;
		unsigned long nDiscType = ui.selectStackerIn->currentData().value<std::pair<int,unsigned long>>().second;
		if ( nStackerIn <= 3 )
		{
			printf("\tstacker %d\n", nStackerIn);
		}
		else
		{
			printf("\tstacker auto\n");
		}
		printf("\tdisc type %lu\n", nDiscType);

		if(PP100API_SUCCESS == nRet)
		{
			switch(nDiscType)
			{
			case PP100API_CD_MINUS_R:
				nRet = PP100_SetDiscType(pJobID, PP100API_CD);
				break;

			case PP100API_DVD_MINUS_R: // obsolated
			case PP100API_DVD_PLUS_R: // obsolated
			case PP100API_DVD_R:
				nRet = PP100_SetDiscType(pJobID, PP100API_DVD);
				break;

			case PP100API_DVD_MINUS_R_DL: // obsolated
			case PP100API_DVD_PLUS_R_DL: // obsolated
			case PP100API_DVD_R_DL:
				nRet = PP100_SetDiscType(pJobID, PP100API_DVD_DL);
				break;

			case PP100API_BD_MINUS_R:
				nRet = PP100_SetDiscType(pJobID, PP100API_BD);
				break;

			case PP100API_BD_MINUS_R_DL:
				nRet = PP100_SetDiscType(pJobID, PP100API_BD_DL);
				break;

			case PP100API_INPUT:
			case PP100API_OUTPUT:
			case PP100API_NOT_USE_STACKER:
				break;

			default:
				assert(0);
				break;
			}
			printf("PP100_SetDiscType() returns %ld\n", nRet);

			// Stacker In
			switch(nStackerIn)
			{
			case 0:
				nRet = PP100_SetInStacker(pJobID, PP100API_STACKER1);
				break;
			case 1:
				nRet = PP100_SetInStacker(pJobID, PP100API_STACKER2);
				break;
			case 2:
				nRet = PP100_SetInStacker(pJobID, PP100API_STACKER1_OR_STACKER2);
				break;
			default:
				break;
			}

			// Stacker Out
			int nStackerOut = ui.selectStackerOut->currentData().value<std::pair<int,unsigned long>>().first;

			switch(nStackerOut)
			{
			case 1:
				nRet = PP100_SetOutStacker(pJobID, PP100API_STACKER2);
				break;
			case 2:
				nRet = PP100_SetOutStacker(pJobID, PP100API_STACKER3);
				break;
			case 3:
				nRet = PP100_SetOutStacker(pJobID, PP100API_STACKER4);
				break;
			default:
				break;
			}

			// Compare
			switch( ui.selectWritingVerification->currentIndex() )
			{
			default:
			case 0:
				PP100_SetCompare(pJobID, PP100API_DONT_COMPARE);
				break;
			case 1:
				PP100_SetCompare(pJobID, PP100API_COMPARE);
				break;
			}

			// DATA
			if ( ui.checkWriteData->isChecked() )
			{
				// File System
				switch( ui.selectFileSystem->currentIndex() )
				{
				default:
				case 0:
					nRet = PP100_SetFormat(pJobID, PP100API_ISO9660L2);
					break;
				case 1:
					nRet = PP100_SetFormat(pJobID, PP100API_UDF102);
					break;
				case 2:
					nRet = PP100_SetFormat(pJobID, PP100API_UDF260);
					break;
				}

				// Volume Label
				nRet = PP100_SetVolumeLabel(pJobID, ui.textVolumeLabel->text().toUtf8().data());

				// Content
				int rows = modelContent->rowCount();

				std::vector<PP100_WRITE_DATA> writeData(rows);
				for(int row=0; row < rows; row++)
				{
					QStandardItem * item = modelContent->item(row);
					Q_CHECK_PTR(item);

					printf("item[%d].text: %s\n", row, qPrintable(item->text()));
					printf("item[%d].toolTip: %s\n", row, qPrintable(item->toolTip()));

					strcpy(writeData[row].pSourceData, item->toolTip().toUtf8().constData());
					strcpy(writeData[row].pDestinationData, item->text().toUtf8().constData());
				}

				nRet = PP100_SetData(pJobID, &writeData[0], writeData.size());
			}

			// LABEL
			if ( ui.checkPrintLabel->isChecked() )
			{
				// Image
				printf("label file: %s\n", qPrintable(ui.textLabelFile->text()));
				nRet = PP100_SetLabel(pJobID, ui.textLabelFile->text().toUtf8().data());

				// Label Type
				switch( ui.selectLableType->currentIndex() )
				{
				default:
				case 0:
					nRet = PP100_SetLabelType(pJobID, PP100API_CD_DVD_LABEL);
					break;
				case 1:
					nRet = PP100_SetLabelType(pJobID, PP100API_CD_DVD_PREMIUM_LABEL);
					break;
				case 2:
					nRet = PP100_SetLabelType(pJobID, PP100API_EPSON_SPECIFIED_CD_DVD_LABEL);
					break;
				}

				// Print Mode
				switch( ui.sliderPrintMode->value() )
				{
				default:
				case 1:
					nRet = PP100_SetPrintMode(pJobID, PP100API_PRINTMODE1);
					break;
				case 2:
					nRet = PP100_SetPrintMode(pJobID, PP100API_PRINTMODE2);
					break;
				}

				// Print Area
				nRet = PP100_SetLabelArea(
					pJobID,
					static_cast<unsigned long>(ui.spinDiameterOutside->value() * 100),
					static_cast<unsigned long>(ui.spinDiameterInside->value()  * 100) );
			}

			// Copies
			nRet = PP100_SetCopies(pJobID, ui.spinCopies->value());
		}
		else
		{
			return false;
		}
		return true;
	}


	bool onPublishClicked(void)
	{
		QString currentOutputDevice = ui.selectOutputDevice->currentText();
		if (
			! currentOutputDevice.isEmpty() &&
			( ui.checkWriteData->isChecked() || ui.checkPrintLabel->isChecked() ) )
		{
			ui.btnPublish->setEnabled(false);
			this->update();
			this->repaint();
			QApplication::processEvents();

			char pJobID[41] = {0};
			long nRet = PP100_CreateJob(pJobID);
			printf("PP100_CreateJob() returns %ld\n", nRet);
			printf("\tpJobID is %s\n", pJobID);

			nRet = PP100_SetPublisher(pJobID, currentOutputDevice.toUtf8().data());
			printf("PP100_SetPublisher() returns %ld\n", nRet);
			printf("\tpJobID is %s\n", pJobID);

			if (SetJobParam(pJobID))
			{
				long nRet = PP100API_SUCCESS;

				// Submit
				nRet = PP100_SubmitJob(m_ulPP100APIServerHandle, pJobID, true);
				printf("PP100_SubmitJob() returns %ld\n", nRet);

				// Get Job Status after submitting
				if ( nRet == PP100API_SUCCESS )
				{
					PP100_JOB_STATUS jobStatus = {0};
					unsigned long ulJobStatusNum = 1;
					nRet = PP100_GetJobStatus(m_ulPP100APIServerHandle, pJobID, &jobStatus, &ulJobStatusNum);
					printf("PP100_GetJobStatus() returns %ld\n", nRet);
					if(PP100API_SUCCESS == nRet && ulJobStatusNum == 1)
					{
						if ( PP100API_SYS001 <= jobStatus.ulErrorCode )
						{
							if( jobStatus.ulErrorCode <= PP100API_SYS003 )
							{
								(void) QMessageBox::warning(
									this,
									tr("Failed"),
									QString::asprintf("SYS%03d", (int)jobStatus.ulErrorCode) );
							}
							else if ( jobStatus.ulErrorCode <= PP100API_JDF2900 )
							{
								(void) QMessageBox::warning(
									this,
									tr("Failed"),
									QString::asprintf("JDF%04d", (int)jobStatus.ulErrorCode) );
							}
							else if ( jobStatus.ulErrorCode <= PP100API_JDF0004 )
							{
								(void) QMessageBox::warning(
									this,
									tr("Failed"),
									QString::asprintf("JDF%04d", (int)jobStatus.ulErrorCode - 5000) );
							}
						}
					}
					else
					{
						printf("Getting JOB Status failed.\n");
					}
				}
				else
				{
					(void) QMessageBox::warning(
						this,
						tr("Failed"),
						QString::asprintf("PP100_SubmitJob() returns %ld", nRet) );
				}
			}

			ui.btnPublish->setEnabled(true);
			return true;
		}
		ui.btnPublish->setEnabled(true);
		return false;
	}


	bool onOutputDeviceChanged(void)
	{
		QString currentOutputDevice = ui.selectOutputDevice->currentText();
		verbose_print("OutputDevice: %s\n", qPrintable(currentOutputDevice));

		ui.selectStackerIn->clear();
		ui.selectStackerOut->clear();

		if ( ! currentOutputDevice.isEmpty() )
		{
			PP100_PUBLISHER_STATUS status = {0};

			long lRet = PP100_GetPublisherStatus(m_ulPP100APIServerHandle, currentOutputDevice.toUtf8().data(), &status);
			if ( lRet == PP100API_SUCCESS )
			{
				// Publish Mode
				verbose_print("\tPublishMode: %lu\n", status.ulMode);
				switch(status.ulMode)
				{
				case PP100API_NORMAL_MODE:
					ui.textMode->setText(tr("Standard mode"));
					break;

				case PP100API_OUTPUT_MODE:
					ui.textMode->setText(tr("External Output / Low-volume mode"));
					break;

				case PP100API_BATCH_MODE:
					ui.textMode->setText(tr("Batch mode"));
					break;

				default:
					ui.textMode->setText(tr("Unknown"));
					break;
				}

				// fitting text size by scaling font
				rescaleFontToFitContent(ui.textMode, ui.textMode->text(), textModePointSizeDefault, textModePointSizeDefault*0.8);

				// Input/Output Stacker
				std::vector<unsigned long> vStackerSettings;
				std::vector<QString> vStackerNames;
				if(status.ulMode == PP100API_BATCH_MODE)
				{
					// Batch mode is auto only
					vStackerSettings.push_back(status.ulStackerSetting[0]);
					vStackerNames.push_back(tr("Auto"));
					vStackerSettings.push_back(status.ulStackerSetting[2]);
					vStackerNames.push_back(tr("Auto"));
				}
				else
				{
					for(size_t i=0; i < 4; i++)
					{
						verbose_print("\tPublishMode[%zd]: %lu\n", i, status.ulStackerSetting[i]);
						vStackerSettings.push_back(status.ulStackerSetting[i]);
						vStackerNames.push_back(tr("Stacker") + QString::asprintf(" %zd", i+1));
					}
					if ( vStackerSettings[0] == vStackerSettings[1] ) // stacker 1 or  2
					{
						vStackerSettings.push_back(status.ulStackerSetting[0]);
						vStackerNames.push_back(tr("Auto"));
					}
				}

				for(size_t i=0; i < vStackerSettings.size(); i++)
				{
					switch(vStackerSettings[i])
					{
					case PP100API_CD_MINUS_R:
					case PP100API_DVD_MINUS_R: // obsolated
					case PP100API_DVD_PLUS_R:  // obsolated
					case PP100API_DVD_R:
					case PP100API_DVD_MINUS_R_DL: // obsolated
					case PP100API_DVD_PLUS_R_DL:  // obsolated
					case PP100API_DVD_R_DL:
					case PP100API_BD_MINUS_R:
					case PP100API_BD_MINUS_R_DL:
						{
							QString media;

							switch(vStackerSettings[i])
							{
							case PP100API_CD_MINUS_R:     media = tr("CD-R");          break;
							case PP100API_DVD_MINUS_R:    // obsolated
							case PP100API_DVD_PLUS_R:     // obsolated
							case PP100API_DVD_R:          media = tr("DVD(+R/-R)");    break;
							case PP100API_DVD_MINUS_R_DL: // obsolated
							case PP100API_DVD_PLUS_R_DL:  // obsolated
							case PP100API_DVD_R_DL:       media = tr("DVD(+R/-R) DL"); break;
							case PP100API_BD_MINUS_R:     media = tr("BD-R");          break;
							case PP100API_BD_MINUS_R_DL:  media = tr("BD-R DL");       break;
							default: assert(0);  break;
							}
							ui.selectStackerIn->addItem(
									vStackerNames[i] + QString(" ") + media,
									QVariant::fromValue(std::pair<int,unsigned long>(i,vStackerSettings[i])) );
						}
						break;

					case PP100API_INPUT:
						ui.selectStackerIn->addItem(
								vStackerNames[i],
								QVariant::fromValue(std::pair<int,unsigned long>(i,vStackerSettings[i])) );
						break;

					case PP100API_OUTPUT:
						ui.selectStackerOut->addItem(
								vStackerNames[i],
								QVariant::fromValue(std::pair<int,unsigned long>(i,vStackerSettings[i])) );
						break;

					case PP100API_NOT_USE_STACKER:
						break;

					default:
						printf("\t\tUNKNOWN stacker val\n");
						break;
					}
				}

				return true;
			}
			else
			{
				printf("PP100_GetPublisherStatus ret %ld\n", lRet);
			}
		}
		return false;
	}


	bool onCheckStateChanged(void)
	{
		QString currentOutputDevice = ui.selectOutputDevice->currentText();
		if (
			! currentOutputDevice.isEmpty() &&
			( ui.checkWriteData->isChecked() || ui.checkPrintLabel->isChecked() ) &&
			ui.selectStackerIn->currentIndex() != -1 &&
			ui.selectStackerOut->currentIndex() != -1 )
		{
			ui.btnPublish->setEnabled(true);
		}
		else
		{
			ui.btnPublish->setEnabled(false);
		}
		return true;
	}


	void dragEnterEvent(QDragEnterEvent *e)
	{
		e->acceptProposedAction();
	}


	void dropEvent(QDropEvent *e)
	{
		for(auto url : e->mimeData()->urls())
		{
			addPathItem(url.toLocalFile());
		}
	}
};



#include "TDMakerLiteMain.moc"

int main( int argc, const char* argv[] )
{
	QApplication app(argc, const_cast<char**>(argv));

	// Qt supports following command line options:
	// -style= style
	// -style style
	// -stylesheet= stylesheet
	// -stylesheet stylesheet
	// -widgetcount
	// -reverse
	// -qmljsdebugger=

	// Command line otptions that are not processed Qt can be obtained by QCoreApplication::arguments().
	for(auto arg : QCoreApplication::arguments())
	{
		if ( arg == "-v" || arg == "--verbose"  )
		{
			verbose = true;
		}
	}

	if ( verbose )
	{
		printf(
			"locale\n"
			"\tname: %s\n"
			"\tlanguage: %s\n"
			"\tzeroDigit: %s\n"
			"\tpositiveSign: %s\n"
			"\tnegativeSign: %s\n"
			"\tdecimalPoint: %s\n",
			qPrintable(QLocale::system().name()),
			qPrintable(QLocale::languageToString(QLocale::system().language())),
			qPrintable(QLocale::system().zeroDigit()),
			qPrintable(QLocale::system().positiveSign()),
			qPrintable(QLocale::system().negativeSign()),
			qPrintable(QLocale::system().decimalPoint()));

		printf("supported image format: ");
		for(auto i : QImageReader::supportedImageFormats())
		{
			printf("%s, ", i.constData());
		}
		printf("\n");

		printf("%s\n", qPrintable(QLibraryInfo::location(QLibraryInfo::TranslationsPath)));
	}

	// https://doc.qt.io/qt-5/internationalization.html
	// localize for Qt embeded strings
	QTranslator qtTr;
	qtTr.load("qt_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
	app.installTranslator(&qtTr);

	// localize for TDMakerLite strings
	QTranslator myTr;
	QString languageCode = QLocale::system().name();
	if ( myTr.load("TDMakerLite_" + languageCode, INSTALL_DIR "/tr/") )
	{
		app.installTranslator(&myTr);
	}
	else
	{
		fprintf(stderr, "ERROR: language file %s is not found\n", qPrintable(languageCode));
	}

	try {
		MainFrame frame;
		frame.show();
		return app.exec();
	}
	catch(int retCode)
	{
		app.exit(retCode);
		exit(retCode);
		return retCode;
	}
	catch(...)
	{
		app.exit(-1);
		exit(-1);
		return -1;
	}

	return -1;
}
