#ifndef TDMONITOR_H
#define TDMONITOR_H

#include <QtCore/QTimer>
#include <memory>
#include <deque>

#include "ui_TDMonitor.h"
#include "PP100API.h"

#define	TCHAR		char
#define	MAX_PATH	(260)
#define _T(x)		x

#if !defined(_countof)
template <typename Type, size_t Size>
char (*__countof_helper(Type (&ar)[Size]))[Size];
#define _countof(ar) sizeof(*__countof_helper(ar))
#endif//!defined(_countof)

const char g_pPP100APIDLL[] = "/opt/epson/Total Disc Maker/lib/libPP100API.so";

class PP100API_POINTER
{
private:
	void * hPP100APIDLL = NULL;
	std::string m_dlerror;

public:
	unsigned long ulHandle = 0;
	PP100_INITIALIZE         PP100_Initialize = NULL;
	PP100_DESTROY            PP100_Destroy = NULL;
	PP100_CONNECTSERVER      PP100_ConnectServer = NULL;
	PP100_DISCONNECTSERVER   PP100_DisConnectServer = NULL;
	PP100_ENUMPUBLISHERS     PP100_EnumPublishers = NULL;
	PP100_GETPUBLISHERSTATUS PP100_GetPublisherStatus = NULL;
	PP100_GETJOBSTATUS       PP100_GetJobStatus = NULL;
	PP100_CANCELJOB          PP100_CancelJob = NULL;

public:
	// Constructor
	PP100API_POINTER() {}
	bool LoadPP100API();
	const char* last_dlerror(void) { return m_dlerror.c_str(); }
};


long endPP100Api();

extern PP100API_POINTER g_Api;

class TDMonitorEx : public QMainWindow, private Ui::TDMonitor
{
	Q_OBJECT

public:
	TDMonitorEx(const char szPublisherName[], QMainWindow *parent = 0);
	~TDMonitorEx();

protected:
	char m_cPublisherName[65] = {};
	std::unique_ptr<QTimer> m_timer;
	std::unique_ptr<QActionGroup> m_exclusivActionShowJobs;

	void updateContent();
	void appendTreeItem(const PP100_JOB_STATUS& jobStatus);
	void setStacker_in(int nCol, const PP100_JOB_STATUS& jobStatus, QTreeWidgetItem *pItem);
	void setStacker_out(int nCol, const PP100_JOB_STATUS& jobStatus, QTreeWidgetItem *pItem);
	void setJobType(int nCol, const PP100_JOB_STATUS& jobStatus, QTreeWidgetItem *pItem);
	void setDeviceInfo(const PP100_PUBLISHER_STATUS& publisherStatus, const std::deque<PP100_JOB_STATUS>& jobStatusPublishing);
	void setDriveInfo(const PP100_PUBLISHER_STATUS& publisherStatus, int drvNum);
	void setStackerSetting(const PP100_PUBLISHER_STATUS& publisherStatus, int stckerNum);
	bool event(QEvent* event);

private slots:
	void cancelJob();
	void selectAllJobs();
	void showUnfinishedJobs();
	void showFinishedJobs();
	void showAboutDialog();
	void changeTab(int num);
	void updatePeriodical();
	void updateMenu();
};

long LoadPP100API(); // Load PP-100 Series API and get function pointers.

#endif // TDMONITOR_H
