#include <stdio.h>
#include <string.h>
#include <dlfcn.h>
#include <QApplication>
#include <QMainWindow>
#include <QDialog>
#include <QWidget>
#include <QtCore/QTranslator>
#include <QtCore/QLibraryInfo>
#include <QMessageBox>

#include "TDMonitor.h"
#include "PublisherSelectDialog.h"

#include "config.h"

PP100API_POINTER g_Api;

int main(int argc, char *argv[])
{
	QApplication app(argc, argv);

	// Qt Localization
	QTranslator qtTr;
	qtTr.load("qt_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
	app.installTranslator(&qtTr);

	QTranslator myTr;
	QString languageCode = QLocale::system().name();
	if ( myTr.load("TDMonitorQt_" + languageCode, INSTALL_DIR "/tr/") )
	{
		app.installTranslator(&myTr);
	}
	else
	{
		printf("ERROR: language file %s is not found\n", qPrintable(languageCode));
		printf("INSTALL_DIR = %s\n", INSTALL_DIR);
	}

	if( ! g_Api.LoadPP100API() )
	{
		(void) QMessageBox::critical(
			NULL,
			QObject::tr("EPSON Total Disc Monitor"),
			QObject::tr("Loading PP-100 Series API failed.\n") + g_Api.last_dlerror());
		return -1;
	}

	// Initialize PP100 Series API.
	long lRet = g_Api.PP100_Initialize();
	if(PP100API_SUCCESS != lRet)
	{
		printf("Initializing PP-100 Series API failed.\n");
		return lRet;
	}

	// Connect to PC that TDBridge is running.
	lRet = g_Api.PP100_ConnectServer(NULL, NULL, &g_Api.ulHandle);
	if(PP100API_SUCCESS != lRet)
	{
		printf("Connecting to PC that TDBridge is running failed.\n");
		return lRet;
	}

	char PublisherName[65] = {};
	if(argc > 1)
	{
		if(strlen(argv[1]) == 0)
		{
			printf("TDMonitor RegistID Error\n");
			endPP100Api();
			return -2;
		}
		printf("argv = %s\n", argv[1]);
		strcpy(PublisherName, argv[1]);
	}
	else
	{
		PublisherSelectDialog dialog;
		dialog.show();
		if(dialog.exec() == QDialog::Accepted)
		{
			PP100_ENUM_PUBLISHER_INFO info = dialog.getSelectPublisher();
			strcpy(PublisherName, info.pPublisherName);
		}
		else
		{
			printf("TDMonitor Cancel End\n");
			endPP100Api();
			return -3;
		}
	}

	TDMonitorEx dialog(PublisherName);
	dialog.show();

	return app.exec();
}

// Load PP100API.so
bool PP100API_POINTER::LoadPP100API()
{
	const char *the_path = g_pPP100APIDLL;
	hPP100APIDLL = dlopen(the_path, RTLD_LAZY);
	if(NULL == hPP100APIDLL)
	{
		m_dlerror = dlerror();
		fprintf(stderr, "Loading PP-100 Series API failed. errno: %d\n%s\n", errno, m_dlerror.c_str());
		return false;
	}

	// Get function pointer of PP100_Initialize() and PP100_Destroy()
	PP100_Initialize         = (PP100_INITIALIZE)         dlsym(hPP100APIDLL, FNSTR_PP100_INITIALIZE);
	PP100_Destroy            = (PP100_DESTROY)            dlsym(hPP100APIDLL, FNSTR_PP100_DESTROY);
	PP100_ConnectServer      = (PP100_CONNECTSERVER)      dlsym(hPP100APIDLL, FNSTR_PP100_CONNECTSERVER);
	PP100_DisConnectServer   = (PP100_DISCONNECTSERVER)   dlsym(hPP100APIDLL, FNSTR_PP100_DISCONNECTSERVER);
	PP100_EnumPublishers     = (PP100_ENUMPUBLISHERS)     dlsym(hPP100APIDLL, FNSTR_PP100_ENUMPUBLISHERS);
	PP100_GetPublisherStatus = (PP100_GETPUBLISHERSTATUS) dlsym(hPP100APIDLL, FNSTR_PP100_GETPUBLISHERSTATUS);
	PP100_GetJobStatus       = (PP100_GETJOBSTATUS)       dlsym(hPP100APIDLL, FNSTR_PP100_GETJOBSTATUS);
	PP100_CancelJob          = (PP100_CANCELJOB)          dlsym(hPP100APIDLL, FNSTR_PP100_CANCELJOB);

	if(	NULL == PP100_Initialize         ||
		NULL == PP100_Destroy            ||
		NULL == PP100_ConnectServer      ||
		NULL == PP100_DisConnectServer   ||
		NULL == PP100_EnumPublishers     ||
		NULL == PP100_GetPublisherStatus ||
		NULL == PP100_GetJobStatus       ||
		NULL == PP100_CancelJob  )
	{
		m_dlerror = dlerror();
		fprintf(stderr, "Getting function address failed. errno: %d\n%s\n", errno, m_dlerror.c_str());
		(void) dlclose(hPP100APIDLL);
		hPP100APIDLL = NULL;
		return false;
	}

	return true;
}
